Enum hermes_cli_framework::output::Result
source · pub enum Result {
Json(Value),
Text(String),
Value(Box<dyn Debug + Send + Sync + 'static>),
Nothing,
}Expand description
The result to display before quitting, can either be a JSON value, some plain text, a value to print with its Debug instance, or nothing.
Variants